<?php
/*
Plugin Name: Firmao CallBack
Plugin URI: https://firmao.pl?ref2=wpchatplugin
Author: Firmao
License: GPLv2 or later
Version: 1.0.1
Text Domain: firmao-callback
Domain Path: /languages
Description: Embeds Firmao CallBack widget to your site
*/

add_action("wp_footer", "add_firmao_callback_widget");

function add_firmao_callback_widget() {
		
        if (esc_attr( get_option('firmao_organization_identifier') ) != "") {
			
			wp_enqueue_script("firmao_call_back", "https://system.firmao.pl:8443/js/callBackPlugin/CallBackPlugin.js",array() , null);
			add_filter( 'script_loader_tag', 'my_script_attributes', 10, 3 );

			function my_script_attributes( $tag, $handle, $src )
			{
				// change to the registered script handle, e. g. 'jquery'
				if ( 'firmao_call_back' === $handle ) {

					// add attributes of your choice
					$tag = '<script id="firmao_call_back" data-org-identifier="' 
						. esc_attr( get_option('firmao_organization_identifier') ) 
						. '" ' . esc_attr( get_option('firmao_additional_parameters') ) 
						. ' src="' . esc_url( $src ) . '"></script>';
				}

				return $tag;
			}
        }
}

add_action( 'init', 'firmao_callback_text_domain' );

function firmao_callback_text_domain() {
    load_plugin_textdomain( 'firmao-callback', false, basename( dirname( __FILE__ ) ) . '/languages' );
}

add_action('admin_menu', 'firmao_callback_create_menu');

function firmao_callback_create_menu() {

    //create new top-level menu
    add_submenu_page('options-general.php', __('Firmao CallBack Settings', 'firmao-callback'), __('Firmao CallBack Settings', 'firmao-callback'), 'administrator', 'firmao_callback_settings_page', 'firmao_callback_settings_page');

    //call register settings function
    add_action( 'admin_init', 'register_firmao_callback_settings_page' );
}


function register_firmao_callback_settings_page() {
    //register our settings
    register_setting( 'firmao_callback-settings-group', 'firmao_organization_identifier' );
    register_setting( 'firmao_callback-settings-group', 'firmao_additional_parameters' );
}

function firmao_callback_settings_page() {
    ?>
    <div class="wrap">
        <h1>Firmao Callback Plugin</h1>

        <form method="post" action="options.php">
            <?php settings_fields( 'firmao_callback-settings-group' ); ?>
            <?php do_settings_sections( 'firmao_callback-settings-group' ); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row"><?php _e( 'Organization Identifier', 'firmao-callback' ) ?></th>
                    <td><input type="text" name="firmao_organization_identifier" value="<?php echo esc_attr( get_option('firmao_organization_identifier') ); ?>" /></td>
                </tr>

                <tr valign="top">
                    <th scope="row"><?php _e( 'Other Options', 'firmao-callback' ) ?></th>
                    <td><input type="text" name="firmao_additional_parameters" value="<?php echo esc_attr( get_option('firmao_additional_parameters') ); ?>" /></td>
                </tr>
                </tr>
            </table>

            <?php submit_button(); ?>

        </form>
    </div>
    <?php
}

register_uninstall_hook(__FILE__, 'firmao_callback_uninstall');

function firmao_callback_uninstall() {
    unregister_setting( 'firmao_callback-settings-group', 'firmao_organization_identifier' );
    unregister_setting( 'firmao_callback-settings-group', 'firmao_additional_parameters' );
}